# Generated by Django 3.2.6 on 2021-09-02 11:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("orgs", "0026_fix_org_config_rapidpro"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="org",
            options={"ordering": ["name"]},
        ),
    ]
