# -*- coding: utf-8 -*-
# Generated by Django 1.11.11 on 2018-03-22 14:15


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("orgs", "0024_populate_org_backend")]

    operations = [
        migrations.AlterField(
            model_name="orgbackend",
            name="api_token",
            field=models.CharField(default="", help_text="The API token for this backend", max_length=128),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="orgbackend",
            name="backend_type",
            field=models.CharField(default="", max_length=256),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="orgbackend",
            name="host",
            field=models.CharField(default="", max_length=128),
            preserve_default=False,
        ),
        migrations.AlterUniqueTogether(name="orgbackend", unique_together=set([("org", "slug")])),
    ]
