# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-03-15 08:23


import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("orgs", "0020_remove_org_api_token")]

    operations = [
        migrations.AlterField(
            model_name="org",
            name="config",
            field=django.contrib.postgres.fields.jsonb.JSONField(
                default=dict,
                help_text="JSON blob used to store configuration information associated with this organization",
            ),
        )
    ]
